<template>
    <div class="dialog-table-container sub-page-inner">
        <div class="sub-table-container" v-if="(queryData.type && (queryData.type == 'list' || queryData.type == 'main'))">
            <el-table ref="dataTable" :element-loading-background="loadingColor" v-loading="loading"
                height="calc(100% - 40px)" highlight-current-row current-row-key="id" :data="tableData" class="dialog_table"
                :header-cell-style="{ 'text-align': 'center' }" row-key="id">
                <el-table-column type="index" align="center" label="序号" width="80"></el-table-column>
                <el-table-column prop="title" label="标题" min-width="160">
                </el-table-column>
                <el-table-column prop="createOrgName" align="center" label="责任单位" width="120">
                </el-table-column>
                <el-table-column type="expand" width="0">
                    <template slot-scope="props">
                        <div :element-loading-background="loadingColor" v-loading="loading" v-html="props.row.content"
                            class="row-content"></div>
                    </template>
                </el-table-column>
                <el-table-column align="center" label="操作" width="130">
                    <template v-slot="{ row }">
                        <el-button type="text" size="mini" @click="expend(row)" class="btn-detail">详细内容<i
                                v-if="!row.expansion" class="el-icon-arrow-right"></i>
                            <i v-else class="el-icon-arrow-down"></i></el-button>
                    </template>
                </el-table-column>
            </el-table>
            <pagenation :pageResult="params.pageBean" @currentChange="pageChange" class="pagenation"></pagenation>
        </div>
        <div v-else class="sub-page-detail" :class="queryData.type && queryData.type == 'detail' ? 'full-detail' : ''">
            <div class="bg-de">
                <!-- <div class="de-con">
                    <div>
                        <img
                            v-for="(item, index) in 2"
                            :key="index"
                            src="@/assets/img/bigScreen/img_wk_zs2@2x.png"
                        />
                    </div>
                    <div class="title">{{ currentRow.title }}</div>
                    <div>
                        <img
                            v-for="(item, index) in 2"
                            :key="index"
                            src="@/assets/img/bigScreen/img_wk_zs2@2x.png"
                        />
                    </div>
                </div> -->
            </div>
            <div class="sub-page--expand" :element-loading-background="loadingColor" v-loading="loading">
                <!-- <div class="content-top">
                    <span>撰稿人：{{ currentRow.drafter }}</span>
                    <span>时间：{{ currentRow.createTime }}</span>
                </div> -->
                <div :element-loading-background="loadingColor" v-loading="loading" v-html="currentRow.title"
                    class="content-main"></div>
                <div :element-loading-background="loadingColor" v-loading="loading" v-html="currentRow.content"
                    class="content-main"></div>
            </div>
        </div>
    </div>
</template>
<script>
import req from '@/request.js'
import apiList from '@/api/bigScreen/districView.js'
import utils from '@/utils.js'
const portal = window.context.portal
import pagenation from './pagenation.vue'
export default {
    components: { pagenation },
    props: {
        options: {
            type: String,
            default: () => {
                return {}
            },
        },
    },
    data() {
        return {
            previewUrl: `${portal}/file/onlinePreviewController/v1/getFileById_`,
            loadingColor: 'rgba(6, 46, 106, 0.4)',
            loading: false,
            tableData: [],
            currentRow: {},
            searchData: {},
            params: {
                pageBean: {
                    page: 1,
                    pageSize: 20,
                    total: 0,
                    showTotal: true,
                },
                params: {},
                querys: [
                    {
                        group: 'main',
                        operation: 'EQUAL',
                        parentGroup: '',
                        property: 'n.OPERATE_TYPE_',
                        relation: 'AND',
                        value: '1',
                    },
                    {
                        group: 'main',
                        operation: 'IN',
                        parentGroup: '',
                        property: 'n.EXCELLENT_',
                        relation: 'AND',
                        value: ['2'],
                    },
                    {
                        group: 'main',
                        operation: 'EQUAL',
                        parentGroup: '',
                        property: 'n.project_Id_',
                        relation: 'AND',
                        value: '',
                    }
                ],
            },
            queryData: {
                type:'',
                id:''
            }
        }
    },
    created() {
        this.$emit('searchDateChange')
    },
    mounted() {
        let { type, id } = this.$route.query
        this.queryData = { type, id }
        if (type == 'detail') {
            this.getDataSingle()
        } else {
            this.loadData()
        }

        this.$bus.$on('changeDate', () => {
            if (this.options.type) {
                this.getDataSingle()
            } else {
                this.loadData()
            }
        })
    },
    beforeDestroy() {
        this.tableData = []
        this.currentRow = {}
    },
    methods: {
        expend(row) {
            let $table = this.$refs.dataTable
            this.tableData.map((item) => {
                if (row.id != item.id) {
                    $table.toggleRowExpansion(item, false)
                    item.expansion = false
                } else {
                    item.expansion = !item.expansion
                }
            })
            $table.toggleRowExpansion(row)
        },
        search(data, type) {
            this.params.pageBean.page = 1
            let RESULT_FORM_ = this.params.querys[0]
            this.params.querys = [RESULT_FORM_]
            for (let key in this.searchData) {
                this.params.querys.push({
                    group: 'main',
                    operation: 'LIKE',
                    parentGroup: '',
                    property: key,
                    relation: 'AND',
                    value: this.searchData[key],
                })
            }
            this.loadData()
        },
        currentChange(currentRow) {
            this.getNewsDetail(currentRow)
        },
        getNewsDetail(column) {
            // this.loading = true
            let api = `/fill/bizWorkNews/v1/findById`
            let formData = new FormData()
            formData.append('id', column.id)
            req.post(portal + api, formData)
                .then((res) => {
                    this.currentRow = (res && res.data) || {}
                    // this.loading = false
                })
                .catch(() => {
                    // this.loading = false
                })
        },
        getDictName(code, value) {
            return utils.getDictName(code, value)
        },
        pageChange(key) {
            this.params.pageBean.page = key
            this.loadData()
        },
        expandChange(row, expandedRows) {
            console.log(row, expandedRows)
            if (row.fileList) return
            this.getFiles(row)
        },
        getFiles(row) {
            this.paramsFile.querys[0].value = row.id
            apiList.getFiles(this.paramsFile, (data) => {
                this.currentRow.fileList = data.rows
            })
        },
        handlePreview(file) {
            let id = file.fileId
                ? file.fileId
                : file.id
                    ? file.id
                    : file.response.fileId
            let type =
                file.fileType ||
                (file.extensionName
                    ? file.extensionName
                    : file.name.split('.')[1])
            this.$refs.filePreview.previewUrl = this.previewUrl + id
            this.$refs.filePreview.open(type)
        },
        // 文件下载
        handleDownloadFile(file) {
            console.log(file)
            let id = file.fileId
                ? file.fileId
                : file.id
                    ? file.id
                    : file.response.fileId
            window.open(portal + `/file/v1/downloadFile?fileId=${id}`, '_self')
        },
        loadData() {
            this.loading = true
            let searchDate = sessionStorage.getItem('searchDate')
            searchDate = JSON.parse(searchDate)
            this.params.params = {
                year: searchDate.year,
                quarter: searchDate.quarter,
            }
            let { type, id } = this.$route.query
            if (type !== 'main') {
                this.params.querys[1].value = ['2', '3']
            }
            this.params.querys[2].value = id
            apiList.getNews(this.params, (res) => {
                if (res && res.rows) {
                    this.tableData = res.rows
                    console.log(res.rows, "==============");
                    this.params.pageBean.page = res.page
                    this.params.pageBean.pageSize = res.pageSize
                    this.params.pageBean.total = res.total
                    if (this.tableData.length) {
                        this.currentRow = this.tableData[0]
                        // this.$nextTick(() => {
                        //     if (!this.$refs.dataTable) return
                        //     this.$refs.dataTable.setCurrentRow(
                        //         this.$refs.dataTable.data[0]
                        //     )
                        // })
                    } else {
                        this.currentRow = {}
                    }
                }
                this.loading = false
            })
        },
        getDataSingle() {
            let { id } = this.$route.query
            this.getNewsDetail({ id })
        },
    },
}
</script>
<style lang="scss" scoped>
.sub-table-container {
    .pagenation {
        margin: 0 !important;
    }
}

.row-content {
    /deep/p {
        padding: 0 90PX;
        margin: 10PX 0;
        color: #fff !important;
        font-size: 16PX;

        span {
            color: #fff !important;
            font-size: 16PX;
        }
    }
}

/deep/ .el-button--text {
    color: #fff;

    span {
        font-size: 16PX;
    }
}

/deep/.el-table__expand-column .cell {
    display: none;
}

.sub-table-container {
    width: 100%;
}

.content-top {
    display: flex;
    justify-content: space-between;
    margin: 0 40px;

    span {
        font-size: 16px;
        color: #d7f1ff;
        font-family: SimHei;
        color: #499dfc;
    }
}

.content-main {
    color: #d7f1ff;
    line-height: 24px;
    font-family: SimHei;
    margin-top: 20px;
    font-size: 16PX;

    /deep/ img {
        max-width: 100%;
    }

    /deep/ p {
        color: #d7f1ff;
        font-size: 16PX;

        span {
            color: #d7f1ff !important;
            font-size: 16PX;
        }
    }
}

.bg-de {
    display: none
}
</style>
<style lang="scss">
@import './table.scss';
</style>
